==> schlix-cms-v2.1.8-7.zip: schlix/system/libs/schlix/view.help.about.skeleton.php <==
<?php
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

if (!defined('SCHLIX_VERSION'))
    die('No Access');
?>
<?php
$icon = \App\Applications::getApplicationIcon($this->app_name);
$package_info = \App\Applications::getPackageInfo('app', $this->app_name);

$app_admin = new \App\Applications_Admin();
?>
<div class="content">
    <div class="row">
        <?php if ($icon): ?>
            <div class="col-xs-5 col-sm-4 col-md-2">
                <img src="<?= \App\Applications::getApplicationIcon($this->app_name) ?>" alt="<?= ___h($this->app_name) ?>" />
            </div>
        <?php endif ?>
        <div class="col-xs-7 col-sm-8 col-md-10">
            <h1><?= $this->app->getApplicationDescription() ?></h1>
        </div>
    </div>
        <?php if ($package_info): ?>
        <table class="table table-condensed">
        <?php foreach ($package_info as $key => $value): ?>
                <tr>
                    <td><?= ___h($key) ?></td>
                    <td><?= ___h($value) ?></td>
                </tr>
        <?php endforeach ?>
        </table>
    <?php endif ?>
    <?php if (!$app_admin->isSystem($this->app_name)): ?>
        <p><a href="<?= $app_admin->createFriendlyAdminURL('action=uninstall&name=' . convert_into_sef_friendly_title($this->app_name)); ?>">
                <i class="fa fa-times-circle"></i> <?= ___('Uninstall') ?></a></p>
    <?php endif ?>    
</div>

==> schlix-cms-v2.2.2-1.zip: schlix/system/libs/schlix/view.help.about.skeleton.php <==
<?php
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC.
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

if (!defined('SCHLIX_VERSION'))
    die('No Access');
?>
<?php
$icon = \App\Core_ApplicationManager::getApplicationIcon($this->app_name);
$package_info = \App\Core_ApplicationManager::getPackageInfo('app', $this->app_name);

$app_admin = new \App\Core_ApplicationManager_Admin();
?>
<div class="content">
    <div class="row">
        <?php if ($icon): ?>
            <div class="col-xs-5 col-sm-4 col-md-2">
                <img src="<?= \App\Core_ApplicationManager::getApplicationIcon($this->app_name) ?>" alt="<?= ___h($this->app_name) ?>" />
            </div>
        <?php endif ?>
        <div class="col-xs-7 col-sm-8 col-md-10">
            <h1><?= $this->app->getApplicationDescription() ?></h1>
        </div>
    </div>
        <?php if ($package_info): ?>
        <table class="table table-condensed">
        <?php foreach ($package_info as $key => $value): ?>
                <tr>
                    <td><?= ___h($key) ?></td>
                    <td><?= ___h($value) ?></td>
                </tr>
        <?php endforeach ?>
        </table>
    <?php endif ?>
    <?php if (!$app_admin->isSystem($this->app_name)): ?>
        <p><a href="<?= $app_admin->createFriendlyAdminURL('action=uninstall&name=' . convert_into_sef_friendly_title($this->app_name)); ?>">
                <i class="fa fa-times-circle"></i> <?= ___('Uninstall') ?></a></p>
    <?php endif ?>    
</div>
